@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2012-2014 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include "mainwindow.h"
@@ -20,7 +9,7 @@
 #include "avogadroappconfig.h"
 #include "backgroundfileformat.h"
 #include "menubuilder.h"
-#include "ui_mainwindow.h"
+#include "tooltipfilter.h"
 #include "viewfactory.h"
 
 #include <avogadro/core/elements.h>
@@ -55,7 +44,9 @@
 #include <QtCore/QString>
 #include <QtCore/QThread>
 #include <QtCore/QTimer>
+#include <QtGui/QClipboard>
 #include <QtGui/QCloseEvent>
+#include <QtGui/QDesktopServices>
 #include <QtGui/QKeySequence>
 #include <QtWidgets/QActionGroup>
 #include <QtWidgets/QApplication>
@@ -75,6 +66,7 @@
 #include <QtWidgets/QPushButton>
 #include <QtWidgets/QTreeView>
 
+#include <QToolButton>
 #include <QtGui/QOpenGLFramebufferObject>
 
 #ifdef QTTESTING
@@ -242,11 +234,9 @@ MainWindow::MainWindow(const QStringList& fileNames, bool disableSettings)
   , m_moleculeDirty(false)
   , m_undo(nullptr)
   , m_redo(nullptr)
+  , m_copyImage(nullptr)
   , m_viewFactory(new ViewFactory)
-  , m_ui(new Ui::MainWindow)
 {
-  m_ui->setupUi(this);
-
   // If disable settings, ensure we create a cleared QSettings object.
   if (disableSettings) {
     QSettings settings;
@@ -265,7 +255,7 @@ MainWindow::MainWindow(const QStringList& fileNames, bool disableSettings)
 
   QList<ExtensionPluginFactory*> extensions =
     plugin->pluginFactories<ExtensionPluginFactory>();
-  qDebug() << "Extension plugins dynamically found..." << extensions.size();
+  qDebug() << "Extension plugins dynamically found…" << extensions.size();
   foreach (ExtensionPluginFactory* factory, extensions) {
     ExtensionPlugin* extension = factory->createInstance();
     if (extension) {
@@ -306,7 +296,7 @@ MainWindow::MainWindow(const QStringList& fileNames, bool disableSettings)
   QTimer::singleShot(3000, this, &MainWindow::registerMoleQueue);
 #endif // Avogadro_ENABLE_RPC
 
-  statusBar()->showMessage(tr("Ready..."), 2000);
+  statusBar()->showMessage(tr("Ready…"), 2000);
 
   updateWindowTitle();
 }
@@ -317,7 +307,6 @@ MainWindow::~MainWindow()
   delete m_molecule;
   delete m_menuBuilder;
   delete m_viewFactory;
-  delete m_ui;
 }
 
 void MainWindow::setupInterface()
@@ -397,10 +386,12 @@ void MainWindow::setupInterface()
 
 #ifndef Q_OS_MAC
   m_fileToolBar->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
-  m_fileToolBar->setWindowTitle(tr("File"));
+  m_fileToolBar->setWindowTitle(tr("File", "File toolbar"));
   addToolBar(m_fileToolBar);
+#else
+  m_fileToolBar->hide();
 #endif
-  m_toolToolBar->setWindowTitle(tr("Tools"));
+  m_toolToolBar->setWindowTitle(tr("Tools", "Tools toolbar"));
   addToolBar(m_toolToolBar);
 
   // Create the scene plugin model
@@ -523,11 +514,28 @@ void setDefaultViews(MultiViewWidget* viewWidget)
         qobject_cast<GLWidget*>(viewWidget->activeWidget())) {
 
     const ScenePluginModel* sceneModel = &glWidget->sceneModel();
+    bool anyPluginTrue = false;
+    // load plugins normally, if all non-ignore are false.
+    // restore the default behavior
     for (auto plugin : sceneModel->scenePlugins()) {
       QString settingsKey("MainWindow/" + plugin->objectName());
       bool enabled = settings.value(settingsKey, plugin->isEnabled()).toBool();
+      if (plugin->defaultBehavior() != ScenePlugin::DefaultBehavior::Ignore &&
+          enabled) {
+        anyPluginTrue = true;
+      }
       plugin->setEnabled(enabled);
     }
+    if (!anyPluginTrue) {
+      for (auto plugin : sceneModel->scenePlugins()) {
+        QString settingsKey("MainWindow/" + plugin->objectName());
+        auto behavior = plugin->defaultBehavior();
+        if (behavior != ScenePlugin::DefaultBehavior::Ignore) {
+          plugin->setEnabled(behavior == ScenePlugin::DefaultBehavior::True);
+          settings.setValue(settingsKey, plugin->isEnabled());
+        }
+      }
+    }
   }
 }
 void MainWindow::setMolecule(Molecule* mol)
@@ -621,9 +629,11 @@ void MainWindow::updateWindowTitle()
   if (m_molecule && m_molecule->hasData("fileName"))
     fileName = QString::fromStdString(m_molecule->data("fileName").toString());
 
-  setWindowTitle(tr("%1%2 - Avogadro %3")
+  setWindowTitle(tr("%1%2 - Avogadro %3",
+                    "window title: %1 = file name, %2 = • for "
+                    "modified file, %3 = Avogadro version")
                    .arg(QFileInfo(fileName).fileName())
-                   .arg(m_moleculeDirty ? "*" : "")
+                   .arg(m_moleculeDirty ? "•" : "")
                    .arg(AvogadroApp_VERSION));
 }
 
@@ -659,6 +669,20 @@ void MainWindow::writeSettings()
   }
 }
 
+void MainWindow::setLocale(const QString& locale)
+{
+  QSettings settings;
+  if (locale.isEmpty()) {
+    settings.remove("locale"); // system is the default
+  } else {
+    settings.setValue("locale", locale);
+  }
+
+  MESSAGEBOX::information(this, tr("Restart needed"),
+                          tr("Please restart Avogadro to use the new "
+                             "language."));
+}
+
 void MainWindow::readSettings()
 {
   QSettings settings;
@@ -738,7 +762,8 @@ bool MainWindow::addScript(const QString& filePath)
   // Ask the user what type of script this is
   // TODO: add some sort of warning?
   QStringList types;
-  types << tr("Commands") << tr("Input Generators") << tr("File Formats");
+  types << tr("Commands") << tr("Input Generators") << tr("File Formats")
+        << tr("Charges", "atomic electrostatics");
 
   bool ok;
   QString item =
@@ -762,6 +787,9 @@ bool MainWindow::addScript(const QString& filePath)
     case 2:
       typePath = "formatScripts";
       break;
+    case 4:
+      typePath = "charges";
+      break;
     default:
       typePath = "other";
   }
@@ -884,17 +912,19 @@ bool MainWindow::backgroundWriterFinished()
   bool success = false;
   if (!m_progressDialog->wasCanceled()) {
     if (m_threadedWriter->success()) {
-      statusBar()->showMessage(tr("File written: %1").arg(fileName));
+      statusBar()->showMessage(
+        tr("Saved file %1", "%1 = filename").arg(fileName));
       m_threadedWriter->molecule()->setData("fileName",
                                             fileName.toLocal8Bit().data());
       markMoleculeClean();
       updateWindowTitle();
       success = true;
     } else {
-      MESSAGEBOX::critical(this, tr("File error"),
-                           tr("Error while writing file '%1':\n%2")
-                             .arg(fileName)
-                             .arg(m_threadedWriter->error()));
+      MESSAGEBOX::critical(
+        this, tr("Error saving file"),
+        tr("Error while saving '%1':\n%2", "%1 = file name, %2 = error message")
+          .arg(fileName)
+          .arg(m_threadedWriter->error()));
     }
   }
   m_fileWriteThread->deleteLater();
@@ -1127,10 +1157,54 @@ void MainWindow::viewActivated(QWidget* widget)
   activeMoleculeEdited();
 }
 
-void MainWindow::exportGraphics()
+QImage MainWindow::renderToImage(const QSize& size)
 {
+  QImage exportImage(size, QImage::Format_ARGB32);
+
   QOpenGLWidget* glWidget =
     qobject_cast<QOpenGLWidget*>(m_multiViewWidget->activeWidget());
+
+  // render it (with alpha channel)
+  Rendering::Scene* scene(nullptr);
+  GLWidget* viewWidget(nullptr);
+  if ((viewWidget =
+         qobject_cast<GLWidget*>(m_multiViewWidget->activeWidget()))) {
+    scene = &viewWidget->renderer().scene();
+  }
+  Vector4ub cColor = scene->backgroundColor();
+  unsigned char alpha = cColor[3];
+  cColor[3] = 0; // 100% transparent for export
+  scene->setBackgroundColor(cColor);
+
+  glWidget->raise();
+  glWidget->repaint();
+  if (QOpenGLFramebufferObject::hasOpenGLFramebufferObjects()) {
+    exportImage = glWidget->grabFramebuffer();
+  } else {
+    QPixmap pixmap = QPixmap::grabWindow(glWidget->winId());
+    exportImage = pixmap.toImage();
+  }
+
+  // set the GL widget back to the right background color (i.e., not 100%
+  // transparent)
+  cColor[3] = alpha; // previous color
+  scene->setBackgroundColor(cColor);
+  glWidget->repaint();
+
+  // Now we embed molecular information into the file, if possible
+  if (m_molecule && m_molecule->atomCount() < 1000) {
+    string tmpCml;
+    bool ok =
+      FileFormatManager::instance().writeString(*m_molecule, tmpCml, "cml");
+    if (ok)
+      exportImage.setText("CML", tmpCml.c_str());
+  }
+
+  return exportImage;
+}
+
+void MainWindow::exportGraphics()
+{
   QStringList filters;
 // Omit "common image formats" on Mac
 #ifdef Q_OS_MAC
@@ -1155,47 +1229,19 @@ void MainWindow::exportGraphics()
   if (QFileInfo(fileName).suffix().isEmpty())
     fileName += ".png";
 
-  // render it (with alpha channel)
-  Rendering::Scene* scene(nullptr);
-  GLWidget* viewWidget(nullptr);
-  if ((viewWidget =
-         qobject_cast<GLWidget*>(m_multiViewWidget->activeWidget()))) {
-    scene = &viewWidget->renderer().scene();
-  }
-  Vector4ub cColor = scene->backgroundColor();
-  unsigned char alpha = cColor[3];
-  cColor[3] = 0; // 100% transparent for export
-  scene->setBackgroundColor(cColor);
-
-  QImage exportImage;
-  glWidget->raise();
-  glWidget->repaint();
-  if (QOpenGLFramebufferObject::hasOpenGLFramebufferObjects()) {
-    exportImage = glWidget->grabFramebuffer();
-  } else {
-    QPixmap pixmap = QPixmap::grabWindow(glWidget->winId());
-    exportImage = pixmap.toImage();
-  }
-
-  // Now we embed molecular information into the file, if possible
-  if (m_molecule && m_molecule->atomCount() < 1000) {
-    string tmpCml;
-    bool ok =
-      FileFormatManager::instance().writeString(*m_molecule, tmpCml, "cml");
-    if (ok)
-      exportImage.setText("CML", tmpCml.c_str());
-  }
+  const QSize size = m_multiViewWidget->activeWidget()->size();
+  QImage exportImage = renderToImage(size);
 
   if (!exportImage.save(fileName)) {
     MESSAGEBOX::warning(this, tr("Avogadro"),
                         tr("Cannot save file %1.").arg(fileName));
   }
+}
 
-  // set the GL widget back to the right background color (i.e., not 100%
-  // transparent)
-  cColor[3] = alpha; // previous color
-  scene->setBackgroundColor(cColor);
-  glWidget->repaint();
+void MainWindow::copyGraphics()
+{
+  QImage exportImage = renderToImage(m_multiViewWidget->activeWidget()->size());
+  QApplication::clipboard()->setImage(exportImage);
 }
 
 void MainWindow::reassignCustomElements()
@@ -1265,6 +1311,11 @@ bool MainWindow::saveFile(bool async)
   QString extension =
     QFileInfo(QString::fromStdString(fileName)).suffix().toLower();
 
+  if (extension.isEmpty()) {
+    fileName += ".cjson";
+    extension = QLatin1String("cjson");
+  }
+
   // Was the original format standard, or imported?
   if (extension == QLatin1String("cml")) {
     return saveFileAs(QString::fromStdString(fileName), new Io::CmlFormat,
@@ -1334,7 +1385,7 @@ bool MainWindow::saveFileAs(bool async)
   else if (extension == "cml")
     writer = new Io::CmlFormat;
   if (extension.isEmpty())
-    fileName += ".cml";
+    fileName += ".cjson";
 
   return saveFileAs(fileName, writer, async);
 }
@@ -1397,9 +1448,11 @@ bool MainWindow::saveFileAs(const QString& fileName, Io::FileFormat* writer,
   m_progressDialog->setRange(0, 0);
   m_progressDialog->setValue(0);
   m_progressDialog->setMinimumDuration(750);
-  m_progressDialog->setWindowTitle(tr("Writing File"));
+  m_progressDialog->setWindowTitle(tr("Saving File in Progress…"));
   m_progressDialog->setLabelText(
-    tr("Writing file '%1'\nwith '%2'").arg(fileName).arg(ident));
+    tr("Saving file “%1”\nwith “%2”", "%1 = file name, %2 = format")
+      .arg(fileName)
+      .arg(ident));
   /// @todo Add API to abort file ops
   m_progressDialog->setCancelButton(nullptr);
   connect(m_fileWriteThread, &QThread::started, m_threadedWriter,
@@ -1622,10 +1675,10 @@ void MainWindow::buildMenu()
   QStringList testingPath;
   testingPath << tr("&Testing");
   QAction* actionRecord = new QAction(this);
-  actionRecord->setText(tr("Record test..."));
+  actionRecord->setText(tr("Record test…"));
   m_menuBuilder->addAction(testingPath, actionRecord, 10);
   QAction* actionPlay = new QAction(this);
-  actionPlay->setText(tr("Play test..."));
+  actionPlay->setText(tr("Play test…"));
   m_menuBuilder->addAction(testingPath, actionPlay, 5);
 
   connect(actionRecord, SIGNAL(triggered()), SLOT(record()));
@@ -1639,7 +1692,7 @@ void MainWindow::buildMenu()
 #endif
 
   QStringList path;
-  path << "&File";
+  path << tr("&File");
   // New
   QAction* action = new QAction(tr("&New"), this);
   action->setShortcut(QKeySequence::New);
@@ -1650,7 +1703,7 @@ void MainWindow::buildMenu()
   m_fileToolBar->addAction(action);
   connect(action, &QAction::triggered, this, &MainWindow::newMolecule);
   // Open
-  action = new QAction(tr("&Open..."), this);
+  action = new QAction(tr("&Open…"), this);
   action->setShortcut(QKeySequence::Open);
 #ifndef Q_OS_MAC
   action->setIcon(QIcon::fromTheme("document-open"));
@@ -1682,7 +1735,7 @@ void MainWindow::buildMenu()
   m_fileToolBar->addAction(action);
   connect(action, &QAction::triggered, this, &MainWindow::saveFile);
   // Save As
-  action = new QAction(tr("Save &As..."), this);
+  action = new QAction(tr("Save &As…"), this);
   action->setShortcut(QKeySequence::SaveAs);
 #ifndef Q_OS_MAC
   action->setIcon(QIcon::fromTheme("document-save-as"));
@@ -1694,16 +1747,16 @@ void MainWindow::buildMenu()
   // Export
   QStringList exportPath = path;
   exportPath << tr("&Export");
-  action = new QAction(tr("&Molecule..."), this);
-  m_menuBuilder->addAction(exportPath, action, 10);
+  action = new QAction(tr("&Molecule…"), this);
+  m_menuBuilder->addAction(exportPath, action, 110);
   m_fileToolBar->addAction(action);
 #ifndef Q_OS_MAC
   action->setIcon(QIcon::fromTheme("document-export"));
 #endif
   connect(action, &QAction::triggered, this, &MainWindow::exportFile);
   // Export graphics
-  action = new QAction(tr("&Graphics..."), this);
-  m_menuBuilder->addAction(exportPath, action, 10);
+  action = new QAction(tr("&Graphics…"), this);
+  m_menuBuilder->addAction(exportPath, action, 100);
 #ifndef Q_OS_MAC
   action->setIcon(QIcon::fromTheme("document-export"));
 #endif
@@ -1720,7 +1773,7 @@ void MainWindow::buildMenu()
 
   // open recent 995 - 985
   // Populate the recent file actions list.
-  path << "Open Recent";
+  path << tr("Open Recent");
   // TODO: Check if files exist and if we actually have 10 items
   for (int i = 0; i < 10; ++i) {
     action = new QAction(QString::number(i), this);
@@ -1749,17 +1802,26 @@ void MainWindow::buildMenu()
   m_redo->setIcon(QIcon::fromTheme("edit-redo"));
 #endif
   m_redo->setShortcut(QKeySequence::Redo);
+
+  m_copyImage = new QAction(tr("&Copy Graphics"), this);
+#ifndef Q_OS_MAC
+  m_copyImage->setIcon(QIcon::fromTheme("edit-copy"));
+#endif
+  m_copyImage->setShortcut(tr("Ctrl+Alt+C"));
+
   m_undo->setEnabled(false);
   m_redo->setEnabled(false);
   connect(m_undo, &QAction::triggered, this, &MainWindow::undoEdit);
   connect(m_redo, &QAction::triggered, this, &MainWindow::redoEdit);
+  connect(m_copyImage, &QAction::triggered, this, &MainWindow::copyGraphics);
   m_menuBuilder->addAction(editPath, m_undo, 1);
   m_menuBuilder->addAction(editPath, m_redo, 0);
+  m_menuBuilder->addAction(editPath, m_copyImage, -10);
 
   // View menu
   QStringList viewPath;
   viewPath << tr("&View");
-  action = new QAction(tr("Set background color..."), this);
+  action = new QAction(tr("Set Background Color…"), this);
   m_menuBuilder->addAction(viewPath, action, 100);
   connect(action, &QAction::triggered, this, &MainWindow::setBackgroundColor);
 
@@ -1795,20 +1857,41 @@ void MainWindow::buildMenu()
   // Periodic table.
   QStringList extensionsPath;
   extensionsPath << tr("&Extensions");
-  action = new QAction("&Periodic Table", this);
+
+  action = new QAction(tr("User Interface Language…"), this);
+  m_menuBuilder->addAction(extensionsPath, action, 100);
+  connect(action, &QAction::triggered, this, &MainWindow::showLanguageDialog);
+
+  action = new QAction(tr("&Periodic Table…"), this);
   m_menuBuilder->addAction(extensionsPath, action, 0);
   QtGui::PeriodicTableView* periodicTable = new QtGui::PeriodicTableView(this);
   connect(action, &QAction::triggered, periodicTable, &QWidget::show);
 
   QStringList helpPath;
   helpPath << tr("&Help");
-  QAction* about = new QAction("&About", this);
+  QAction* about = new QAction(tr("&About"), this);
 #ifndef Q_OS_MAC
   about->setIcon(QIcon::fromTheme("help-about"));
 #endif
-  m_menuBuilder->addAction(helpPath, about, 20);
+  m_menuBuilder->addAction(helpPath, about, 500);
   connect(about, &QAction::triggered, this, &MainWindow::showAboutDialog);
 
+  QAction* forum = new QAction(tr("&Discussion Forum"), this);
+  m_menuBuilder->addAction(helpPath, forum, 200);
+  connect(forum, &QAction::triggered, this, &MainWindow::openForum);
+
+  QAction* website = new QAction(tr("&Avogadro Website"), this);
+  m_menuBuilder->addAction(helpPath, website, 40);
+  connect(website, &QAction::triggered, this, &MainWindow::openWebsite);
+
+  QAction* bug = new QAction(tr("&Report a Bug"), this);
+  m_menuBuilder->addAction(helpPath, bug, 20);
+  connect(bug, &QAction::triggered, this, &MainWindow::openBugReport);
+
+  QAction* feature = new QAction(tr("&Suggest a Feature"), this);
+  m_menuBuilder->addAction(helpPath, feature, 10);
+  connect(feature, &QAction::triggered, this, &MainWindow::openFeatureRequest);
+
   // Now actually add all menu entries.
   m_menuBuilder->buildMenuBar(menuBar());
 }
@@ -1825,6 +1908,29 @@ bool ToolSort(const ToolPlugin* a, const ToolPlugin* b)
   return a->priority() < b->priority();
 }
 
+void MainWindow::showLanguageDialog()
+{
+  bool ok;
+  int currentIndex = 0;
+  m_translationList[0] = tr("System Language");
+
+  QSettings settings;
+  QString currentLanguage = settings.value("locale", "System").toString();
+  if (currentLanguage != "System")
+    currentIndex = m_localeCodes.indexOf(currentLanguage);
+
+  QString item =
+    QInputDialog::getItem(this, tr("Language"), tr("User Interface Language:"),
+                          m_translationList, currentIndex, false, &ok);
+
+  if (ok && !item.isEmpty()) {
+    auto index = m_translationList.indexOf(item);
+    if (index != -1) {
+      setLocale(m_localeCodes[index]);
+    }
+  }
+}
+
 void MainWindow::buildTools()
 {
   PluginManager* plugin = PluginManager::instance();
@@ -1834,6 +1940,7 @@ void MainWindow::buildTools()
     plugin->pluginFactories<ToolPluginFactory>();
   foreach (ToolPluginFactory* factory, toolPluginFactories) {
     ToolPlugin* tool = factory->createInstance();
+    tool->setParent(this);
     if (tool)
       m_tools << tool;
   }
@@ -1841,24 +1948,27 @@ void MainWindow::buildTools()
   // sort them based on priority
   std::sort(m_tools.begin(), m_tools.end(), ToolSort);
 
-  QActionGroup* toolActions = new QActionGroup(this);
   int index = 1;
   foreach (ToolPlugin* toolPlugin, m_tools) {
     // Add action to toolbar.
     toolPlugin->setParent(this);
     QAction* action = toolPlugin->activateAction();
-    action->setParent(toolPlugin);
+    action->setParent(m_toolToolBar);
     action->setCheckable(true);
     if (index < 10)
       action->setShortcut(QKeySequence(QString("Ctrl+%1").arg(index)));
     action->setData(toolPlugin->objectName());
-    qDebug() << toolPlugin->objectName() << "added";
-    toolActions->addAction(action);
+    m_toolToolBar->addAction(action);
+
     connect(action, &QAction::triggered, this, &MainWindow::toolActivated);
     ++index;
   }
 
-  m_toolToolBar->addActions(toolActions->actions());
+  // add the fake tooltip method
+  ToolTipFilter* filter = new ToolTipFilter(this);
+  foreach (QToolButton* button, m_toolToolBar->findChildren<QToolButton*>()) {
+    button->installEventFilter(filter);
+  }
 }
 
 QString MainWindow::extensionToWildCard(const QString& extension)
@@ -1930,7 +2040,7 @@ bool MainWindow::saveFileIfNeeded()
     // look more "native."
     QPointer<MESSAGEBOX> msgBox = new MESSAGEBOX(
       QMessageBox::Warning, tr("Avogadro"),
-      tr("Do you want to save the changes you made in the document?"),
+      tr("Do you want to save the changes to the document?"),
       QMessageBox::Save | QMessageBox::Discard | QMessageBox::Cancel, this);
 
     // On Mac, this will make a sheet relative to the window
@@ -1949,9 +2059,6 @@ bool MainWindow::saveFileIfNeeded()
       ->setShortcut(QKeySequence(tr("Ctrl+S", "Save")));
     msgBox->button(QMessageBox::Discard)
       ->setShortcut(QKeySequence(tr("Ctrl+D", "Discard")));
-    //    msgBox->setButtonText(QMessageBox::Save,
-    //                          isDefaultFileName(d->fileName) ? tr("Save...") :
-    //                          tr("Save"));
 
     int response = msgBox->exec();
 
@@ -2008,6 +2115,30 @@ void MainWindow::showAboutDialog()
   about.exec();
 }
 
+void MainWindow::openForum()
+{
+  QDesktopServices::openUrl(QUrl("https://discuss.avogadro.cc/"));
+}
+
+void MainWindow::openWebsite()
+{
+  QDesktopServices::openUrl(QUrl("https://two.avogadro.cc/"));
+}
+
+void MainWindow::openBugReport()
+{
+  QDesktopServices::openUrl(
+    QUrl("https://github.com/OpenChemistry/avogadrolibs/issues/"
+         "new?template=bug_report.md"));
+}
+
+void MainWindow::openFeatureRequest()
+{
+  QDesktopServices::openUrl(
+    QUrl("https://github.com/OpenChemistry/avogadrolibs/issues/"
+         "new?template=feature_request.md"));
+}
+
 void MainWindow::fileFormatsReady()
 {
   ExtensionPlugin* extension(qobject_cast<ExtensionPlugin*>(sender()));
@@ -2015,7 +2146,7 @@ void MainWindow::fileFormatsReady()
     return;
   foreach (FileFormat* format, extension->fileFormats()) {
     if (!FileFormatManager::registerFormat(format)) {
-      qWarning() << tr("Error while loading FileFormat with id '%1'.")
+      qWarning() << tr("Error while loading the “%1” file format.")
                       .arg(QString::fromStdString(format->identifier()));
       // Need to delete the format if the manager didn't take ownership:
       delete format;
@@ -2031,13 +2162,13 @@ void MainWindow::readQueuedFiles()
     QString file = m_queuedFiles.first();
     m_queuedFiles.removeFirst();
     const FileFormat* format = QtGui::FileFormatDialog::findFileFormat(
-      this, tr("Select file reader"), file, FileFormat::File | FileFormat::Read,
+      this, tr("Select file format"), file, FileFormat::File | FileFormat::Read,
       "Avogadro:");
 
     if (!openFile(file, format ? format->newInstance() : nullptr)) {
       MESSAGEBOX::warning(this, tr("Cannot open file"),
-                          tr("Avogadro timed out and doesn't know how to open"
-                             " '%1'.")
+                          tr("Avogadro cannot open"
+                             " “%1”.")
                             .arg(file));
     }
   }
@@ -2047,8 +2178,8 @@ void MainWindow::clearQueuedFiles()
 {
   if (!m_queuedFilesStarted && !m_queuedFiles.isEmpty()) {
     MESSAGEBOX::warning(this, tr("Cannot open files"),
-                        tr("Avogadro timed out and cannot open"
-                           " '%1'.")
+                        tr("Avogadro cannot open"
+                           " “%1”.")
                           .arg(m_queuedFiles.join("\n")));
     m_queuedFiles.clear();
   }
