@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2012-2016 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #ifndef AVOGADRO_MAINWINDOW_H
@@ -29,7 +18,6 @@ class QThread;
 class QTreeView;
 
 namespace Ui {
-class MainWindow;
 class AboutDialog;
 }
 
@@ -121,6 +109,15 @@ public:
    */
   void readSettings();
 
+  /**
+   * Set the list of possible translations
+   */
+  void setTranslationList(const QStringList& list, const QStringList& codes)
+  {
+    m_translationList = list;
+    m_localeCodes = codes;
+  }
+
 signals:
   /**
    * Emitted when the active molecule in the application has changed.
@@ -135,6 +132,12 @@ protected:
   void dropEvent(QDropEvent* event);
 
 protected slots:
+
+  /**
+   * Set the preferred locale
+   */
+  void setLocale(const QString& locale);
+
   /**
    * Slot provided for extensions to indicate a molecule is ready to be read in.
    * This slot will then pass a molecule to the extension for the data to be
@@ -240,6 +243,16 @@ protected slots:
 private slots:
   void showAboutDialog();
 
+  void showLanguageDialog();
+
+  void openForum();
+
+  void openWebsite();
+
+  void openBugReport();
+
+  void openFeatureRequest();
+
   /**
    * @brief Register file formats from extensions when ready.
    */
@@ -316,8 +329,12 @@ private slots:
    */
   void viewActivated(QWidget* widget);
 
+  QImage renderToImage(const QSize& size);
+
   void exportGraphics();
 
+  void copyGraphics();
+
   void setBackgroundColor();
 
   void setProjectionOrthographic();
@@ -336,6 +353,9 @@ private:
   QStringList m_recentFiles;
   QList<QAction*> m_actionRecentFiles;
 
+  QStringList m_translationList;
+  QStringList m_localeCodes;
+
   MenuBuilder* m_menuBuilder;
 
   // These variables take care of background file reading.
@@ -363,6 +383,7 @@ private:
 
   QAction* m_undo;
   QAction* m_redo;
+  QAction* m_copyImage;
   QAction* m_viewPerspective;
   QAction* m_viewOrthographic;
 
@@ -374,8 +395,6 @@ private:
   bool m_testExit;
 #endif
 
-  Ui::MainWindow* m_ui; // used for the default menu bar
-
   /**
    * Set up the main window widgets, connect signals and slots, etc.
    */
